let books = [];

// Load books from localStorage
if (localStorage.getItem('books')) {
  books = JSON.parse(localStorage.getItem('books'));
  displayBooks();
}

// Form submission
document.getElementById('book-form').addEventListener('submit', function(e) {
  e.preventDefault();
  
  const newBook = {
    isbn: document.getElementById('isbn').value,
    title: document.getElementById('title').value,
    author: document.getElementById('author').value,
    publisher: document.getElementById('publisher').value,
    pubDate: document.getElementById('pub-date').value,
    cover: document.getElementById('cover').value || 'https://via.placeholder.com/150x200',
    tags: document.getElementById('tags').value.split(',').map(tag => tag.trim())
  };
  
  books.push(newBook);
  saveBooks();
  displayBooks();
  this.reset();
});

// Search functionality
document.getElementById('search-btn').addEventListener('click', function() {
  const query = document.getElementById('search-input').value.toLowerCase();
  const filteredBooks = books.filter(book => 
    book.title.toLowerCase().includes(query) ||
    book.isbn.includes(query) ||
    book.author.toLowerCase().includes(query)
  );
  displayBooks(filteredBooks);
});

function displayBooks(booksToDisplay = books) {
  const booksGrid = document.getElementById('books-grid');
  booksGrid.innerHTML = '';
  
  booksToDisplay.forEach(book => {
    const bookCard = document.createElement('div');
    bookCard.className = 'book-card';
    
    bookCard.innerHTML = `
      <img src="${book.cover}" alt="${book.title}" class="book-cover">
      <div class="book-info">
        <h3>${book.title}</h3>
        <p>Author: ${book.author}</p>
        <p>Publisher: ${book.publisher}</p>
        <p>Published: ${new Date(book.pubDate).toLocaleDateString()}</p>
        <div class="book-tags">
          ${book.tags.map(tag => `<span class="tag">${tag}</span>`).join('')}
        </div>
      </div>
    `;
    
    booksGrid.appendChild(bookCard);
  });
}

function saveBooks() {
  localStorage.setItem('books', JSON.stringify(books));
}